@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 import argparse
+import ast
 import bz2
 import csv
 import datetime
@@ -7,8 +8,12 @@ import decimal
 import gzip
 import itertools
 import lzma
+import os
+import re
 import sys
 import warnings
+from codecs import BOM_UTF8
+from glob import glob
 from os.path import splitext
 
 import agate
@@ -73,6 +78,11 @@ class CSVKitUtility:
         """
         Perform argument processing and other setup for a CSVKitUtility.
         """
+        if args is None:
+            args = sys.argv[1:]
+        if os.name == 'nt':
+            args = _expand_args(args)
+
         self._init_common_parser()
         self.add_arguments()
         self.args = self.argparser.parse_args(args)
@@ -125,6 +135,9 @@ class CSVKitUtility:
         if 'f' not in self.override_flags:
             self.input_file = self._open_input_file(self.args.input_path)
 
+        if getattr(self.args, 'add_bom', False):
+            self.output_file.buffer.write(BOM_UTF8)
+
         try:
             with warnings.catch_warnings():
                 if getattr(self.args, 'no_header_row', None):
@@ -189,7 +202,7 @@ class CSVKitUtility:
                 help='Maximum length of a single field in the input CSV file.')
         if 'e' not in self.override_flags:
             self.argparser.add_argument(
-                '-e', '--encoding', dest='encoding', default='utf-8-sig',
+                '-e', '--encoding', dest='encoding', default=os.getenv('PYTHONIOENCODING', 'utf-8-sig'),
                 help='Specify the encoding of the input CSV file.')
         if 'L' not in self.override_flags:
             self.argparser.add_argument(
@@ -199,22 +212,22 @@ class CSVKitUtility:
             self.argparser.add_argument(
                 '-S', '--skipinitialspace', dest='skipinitialspace', action='store_true',
                 help='Ignore whitespace immediately following the delimiter.')
-        if 'blanks' not in self.override_flags:
+        if 'I' not in self.override_flags:
             self.argparser.add_argument(
                 '--blanks', dest='blanks', action='store_true',
                 help='Do not convert "", "na", "n/a", "none", "null", "." to NULL.')
-        if 'blanks' not in self.override_flags:
             self.argparser.add_argument(
                 '--null-value', dest='null_values', nargs='+', default=[],
                 help='Convert this value to NULL. --null-value can be specified multiple times.')
-        if 'date-format' not in self.override_flags:
             self.argparser.add_argument(
                 '--date-format', dest='date_format',
                 help='Specify a strptime date format string like "%%m/%%d/%%Y".')
-        if 'datetime-format' not in self.override_flags:
             self.argparser.add_argument(
                 '--datetime-format', dest='datetime_format',
                 help='Specify a strptime datetime format string like "%%m/%%d/%%Y %%I:%%M %%p".')
+            self.argparser.add_argument(
+                '--no-leading-zeroes', dest='no_leading_zeroes', action='store_true',
+                help='Do not convert a numeric value with leading zeroes to a number.')
         if 'H' not in self.override_flags:
             self.argparser.add_argument(
                 '-H', '--no-header-row', dest='no_header_row', action='store_true',
@@ -235,6 +248,10 @@ class CSVKitUtility:
                 '-l', '--linenumbers', dest='line_numbers', action='store_true',
                 help='Insert a column of line numbers at the front of the output. Useful when piping to grep or as a '
                      'simple primary key.')
+        if 'add-bom' not in self.override_flags:
+            self.argparser.add_argument(
+                '--add-bom', dest='add_bom', action='store_true',
+                help='Add the UTF-8 byte-order mark (BOM) to the output, for Excel compatibility')
 
         # Input/Output
         if 'zero' not in self.override_flags:
@@ -244,7 +261,7 @@ class CSVKitUtility:
                      '1-based numbering.')
 
         self.argparser.add_argument(
-            '-V', '--version', action='version', version='%(prog)s 2.0.1',
+            '-V', '--version', action='version', version='%(prog)s 2.1.0',
             help='Display version information and exit.')
 
     def _open_input_file(self, path, opened=False):
@@ -321,9 +338,10 @@ class CSVKitUtility:
                 # Special case handling for Unicode errors, which behave very strangely
                 # when cast with unicode()
                 if t == UnicodeDecodeError:
-                    sys.stderr.write('Your file is not "%s" encoded. Please specify the correct encoding with the -e '
-                                     'flag or with the PYTHONIOENCODING environment variable. Use the -v flag to see '
-                                     'the complete error.\n' % self.args.encoding)
+                    sys.stderr.write(
+                        'Your file is not "%s" encoded. Please specify the correct encoding with the --encoding flag.'
+                        ' Use the -v flag to see the complete error.\n' % self.args.encoding
+                    )
                 else:
                     sys.stderr.write(f'{t.__name__}: {str(value)}\n')
 
@@ -338,27 +356,33 @@ class CSVKitUtility:
             type_kwargs['null_values'].append(null_value)
 
         text_type = agate.Text(**type_kwargs)
-        number_type = agate.Number(locale=self.args.locale, **type_kwargs)
 
         if getattr(self.args, 'no_inference', None):
             types = [text_type]
-        elif getattr(self.args, 'out_quoting', None) == 2:
-            types = [number_type, text_type]
         else:
-            # See the order in the `agate.TypeTester` class.
-            types = [
-                agate.Boolean(**type_kwargs),
-                agate.TimeDelta(**type_kwargs),
-                agate.Date(date_format=self.args.date_format, **type_kwargs),
-                agate.DateTime(datetime_format=self.args.datetime_format, **type_kwargs),
-                text_type,
-            ]
+            number_type = agate.Number(
+                locale=self.args.locale, no_leading_zeroes=getattr(self.args, 'no_leading_zeroes', None), **type_kwargs
+            )
 
-            # In order to parse dates like "20010101".
-            if self.args.date_format or self.args.datetime_format:
-                types.insert(-1, number_type)
+            if getattr(self.args, 'out_quoting', None) == 2:  # QUOTE_NONUMERIC
+                types = [number_type, text_type]
             else:
-                types.insert(1, number_type)
+                # See the order in the `agate.TypeTester` class.
+                types = [
+                    agate.Boolean(**type_kwargs),
+                    agate.TimeDelta(**type_kwargs),
+                    agate.Date(date_format=self.args.date_format, **type_kwargs),
+                    agate.DateTime(datetime_format=self.args.datetime_format, **type_kwargs),
+                    text_type,
+                ]
+
+                # In order to parse dates like "20010101".
+                if self.args.datetime_format:
+                    types.insert(-1, number_type)
+                elif self.args.date_format:
+                    types.insert(-2, number_type)
+                else:
+                    types.insert(1, number_type)
 
         return agate.TypeTester(types=types)
 
@@ -537,7 +561,8 @@ def parse_column_identifiers(ids, column_names, column_offset=1, excluded_column
                 elif '-' in c:
                     a, b = c.split('-', 1)
                 else:
-                    raise
+                    # Ignore unknown columns.
+                    continue
 
                 try:
                     a = int(a) if a else 1
@@ -550,3 +575,35 @@ def parse_column_identifiers(ids, column_names, column_offset=1, excluded_column
                     excludes.append(match_column_identifier(column_names, x, column_offset))
 
     return [c for c in columns if c not in excludes]
+
+
+def parse_list(pairs):
+    options = {}
+    for key, value in pairs:
+        try:
+            value = ast.literal_eval(value)
+        except ValueError:
+            pass
+        options[key] = value
+    return options
+
+
+# Adapted from https://github.com/pallets/click/blame/main/src/click/utils.py
+def _expand_args(args):
+    out = []
+
+    for arg in args:
+        arg = os.path.expanduser(arg)
+        arg = os.path.expandvars(arg)
+
+        try:
+            matches = glob(arg, recursive=True)
+        except re.error:
+            matches = []
+
+        if matches:
+            out.extend(matches)
+        else:
+            out.append(arg)
+
+    return out
