@@ -58,6 +58,10 @@ class TestIn2CSV(CSVKitTestCase, EmptyFileTests):
         self.assertConverted('csv', 'examples/test_locale.csv',
                              'examples/test_locale_converted.csv', ['--locale', 'de_DE'])
 
+    def test_add_bom(self):
+        self.assertConverted('csv', 'examples/test_utf8.csv',
+                             'examples/test_utf8_bom.csv', ['--add-bom'])
+
     def test_no_blanks(self):
         self.assertConverted('csv', 'examples/blanks.csv', 'examples/blanks_converted.csv')
 
@@ -86,6 +90,10 @@ class TestIn2CSV(CSVKitTestCase, EmptyFileTests):
 
         input_file.close()
 
+    def test_no_leading_zeroes(self):
+        self.assertConverted('csv', 'examples/test_no_leading_zeroes.csv',
+                             'examples/test_no_leading_zeroes.csv', ['--no-leading-zeroes'])
+
     def test_date_format(self):
         self.assertConverted('csv', 'examples/test_date_format.csv',
                              'examples/test_date_format_converted.csv', ['--date-format', '%d/%m/%Y'])
